@@ -57,14 +57,14 @@ void NoteListWidget::setNotes(const Akonadi::Item::List &notes)
 {
     clear();
     d->mNotes = notes;
-    for (const Akonadi::Item &note : qAsConst(d->mNotes)) {
+    for (const Akonadi::Item &note : std::as_const(d->mNotes)) {
         createItem(note);
     }
 }
 
 void NoteListWidget::createItem(const Akonadi::Item &note)
 {
-    KMime::Message::Ptr noteMessage = note.payload<KMime::Message::Ptr>();
+    auto noteMessage = note.payload<KMime::Message::Ptr>();
     if (!noteMessage) {
         return;
     }
